==> intel-media-driver_22.4.3+dfsg1.orig.tar.xz: media-driver-intel-media-22.4.3/media_driver/agnostic/gen12/vp/hal/media_srcs.cmake <==
# Copyright (c) 2019-2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_composite_g12.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_sfc_g12_base.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_g12_base.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_renderer_g12.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_memdecomp_g12.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_composite_g12.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_sfc_g12_base.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_g12_base.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_renderer_g12.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_memdecomp_g12.h
)


set(VP_SOURCES_
    ${VP_SOURCES_}
    ${TMP_SOURCES_}
)

set(VP_HEADERS_
    ${VP_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "VpHal\\Render" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )
set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")

media_add_curr_to_include_path()

==> intel-media-driver_25.4.2+dfsg1.orig.tar.xz: media-driver-intel-media-25.4.2/media_driver/agnostic/gen12/vp/hal/media_srcs.cmake <==
# Copyright (c) 2019-2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_composite_g12.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_sfc_g12_base.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_g12_base.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_renderer_g12.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_memdecomp_g12.cpp
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_hdr_3dlut_g12.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_composite_g12.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_sfc_g12_base.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_g12_base.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_renderer_g12.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_vebox_memdecomp_g12.h
    ${CMAKE_CURRENT_LIST_DIR}/vphal_render_hdr_3dlut_g12.h
)


set(VP_SOURCES_
    ${VP_SOURCES_}
    ${TMP_SOURCES_}
)

set(VP_HEADERS_
    ${VP_HEADERS_}
    ${TMP_HEADERS_}
)

source_group( "VpHal\\Render" FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )
set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")

set(VP_PRIVATE_INCLUDE_DIRS_
    ${VP_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
